@@ -17,14 +17,16 @@ You should have received a copy of the GNU General Public License
 along with CVXPY.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-__version__ = "0.2.16"
+__version__ = "0.2.18"
 from cvxpy.atoms import *
 from cvxpy.expressions.variables import Variable, Semidef, Bool, Int
 from cvxpy.expressions.constants import Parameter, CallbackParam, Constant
 from cvxpy.problems.problem import Problem
 from cvxpy.problems.objective import Maximize, Minimize
+from cvxpy.problems.solvers.utilities import installed_solvers
 from cvxpy.error import SolverError
-from cvxpy.settings import (CVXOPT, ECOS, ECOS_BB, SCS,
+from cvxpy.settings import (CVXOPT, GLPK, GLPK_MI,
+ECOS, ECOS_BB, SCS, GUROBI_LIN,
 OPTIMAL, UNBOUNDED, INFEASIBLE, SOLVER_ERROR,
 OPTIMAL_INACCURATE, UNBOUNDED_INACCURATE, INFEASIBLE_INACCURATE)
 
