@@ -30,9 +30,10 @@ class log(Elementwise):
     def __init__(self, x):
         super(log, self).__init__(x)
 
-    # Returns the elementwise natural log of x.
     @Elementwise.numpy_numeric
     def numeric(self, values):
+        """Returns the elementwise natural log of x.
+        """
         return np.log(values[0])
 
     # Always unknown.
