@@ -17,10 +17,10 @@ You should have received a copy of the GNU General Public License
 along with CVXPY.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-from max import max
+from cvxpy.atoms.elementwise.max_elemwise import max_elemwise
 
 def pos(x):
-    """ Alias for max{x,0}.
-    
+    """ Alias for max_elemwise{x,0}.
+
     """
-    return max(x,0)
+    return max_elemwise(x, 0)
