@@ -36,19 +36,24 @@ class normInf(Atom):
         cols = values[0].shape[1]
         return max([LA.norm(values[0][:,i], np.inf) for i in range(cols)])
 
-    # Resolves to a scalar.
     def shape_from_args(self):
-        return u.Shape(1,1)
+        """Resolves to a scalar.
+        """
+        return u.Shape(1, 1)
 
-    # Always positive.
     def sign_from_args(self):
+        """Always positive.
+        """
         return u.Sign.POSITIVE
 
-    # Default curvature.
     def func_curvature(self):
+        """Default curvature is convex.
+        """
         return u.Curvature.CONVEX
 
     def monotonicity(self):
+        """Increasing for positive arguments and decreasing for negative.
+        """
         return [u.monotonicity.SIGNED]
 
     @staticmethod
