@@ -18,8 +18,9 @@ along with CVXPY.  If not, see <http://www.gnu.org/licenses/>.
 """
 
 import cvxpy.utilities as u
+from cvxpy.constraints.constraint import Constraint
 
-class NonlinearConstraint(object):
+class NonlinearConstraint(Constraint):
     """
     A nonlinear inequality constraint:
         f(x) <= 0
