@@ -20,7 +20,7 @@ along with CVXPY.  If not, see <http://www.gnu.org/licenses/>.
 from ... import settings as s
 from ... import utilities as u
 from ... import interface as intf
-from constant import Constant
+from .constant import Constant
 import cvxpy.lin_ops.lin_utils as lu
 
 class Parameter(Constant):
