@@ -19,7 +19,7 @@ along with CVXPY.  If not, see <http://www.gnu.org/licenses/>.
 
 # Utility functions to solve circular imports.
 def constant():
-    import constants
+    from cvxpy.expressions import constants
     return constants.Constant
 
 def add_expr():
@@ -30,6 +30,10 @@ def mul_expr():
     from cvxpy.atoms.affine import binary_operators
     return binary_operators.MulExpression
 
+def rmul_expr():
+    from cvxpy.atoms.affine import binary_operators
+    return binary_operators.RMulExpression
+
 def div_expr():
     from cvxpy.atoms.affine import binary_operators
     return binary_operators.DivExpression
@@ -42,6 +46,10 @@ def index():
     from cvxpy.atoms.affine import index
     return index.index
 
+def reshape():
+    from cvxpy.atoms.affine import reshape
+    return reshape.reshape
+
 def transpose():
     from cvxpy.atoms.affine import transpose
     return transpose.transpose
