@@ -17,4 +17,4 @@ You should have received a copy of the GNU General Public License
 along with CVXPY.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-from matrix_utilities import *
\ No newline at end of file
+from cvxpy.interface.matrix_utilities import *
\ No newline at end of file
