@@ -176,7 +176,7 @@ def trace_mat(lin_op):
     """
     rows, _ = lin_op.args[0].size
     mat = np.zeros((1, rows**2))
-    for i in xrange(rows):
+    for i in range(rows):
         mat[0, i*rows + i] = 1
     return [np.matrix(mat)]
 
@@ -269,6 +269,28 @@ def mul_mat(lin_op):
         constant = sp.block_diag(lin_op.size[1]*[constant]).tocsc()
     return [constant]
 
+def rmul_mat(lin_op):
+    """Returns the coefficient matrix for RMUL linear op.
+
+    Parameters
+    ----------
+    lin_op : LinOp
+        The rmul linear op.
+
+    Returns
+    -------
+    list of SciPy CSC matrix or scalar.
+        The matrix for the multiplication on the right operator.
+    """
+    constant = const_mat(lin_op.data)
+    # Scalars don't need to be replicated.
+    if not intf.is_scalar(constant):
+        # Matrix is the kronecker product of constant.T and identity.
+        # Each column in the product is a linear combination of the
+        # columns of the left hand multiple.
+        constant = sp.kron(constant.T, sp.eye(lin_op.size[0])).tocsc()
+    return [constant]
+
 def index_mat(lin_op):
     """Returns the coefficient matrix for indexing.
 
@@ -320,8 +342,8 @@ def transpose_mat(lin_op):
     val_arr = []
     row_arr = []
     col_arr = []
-    for col in xrange(cols):
-        for row in xrange(rows):
+    for col in range(cols):
+        for row in range(rows):
             # Index in transposed coeff.
             row_arr.append(col*rows + row)
             # Index in original coeff.
@@ -349,7 +371,7 @@ def diag_vec_mat(lin_op):
     val_arr = []
     row_arr = []
     col_arr = []
-    for i in xrange(rows):
+    for i in range(rows):
         # Index in the diagonal matrix.
         row_arr.append(i*rows + i)
         # Index in the original vector.
@@ -377,7 +399,7 @@ def diag_mat_mat(lin_op):
     val_arr = []
     row_arr = []
     col_arr = []
-    for i in xrange(rows):
+    for i in range(rows):
         # Index in the original matrix.
         col_arr.append(i*rows + i)
         # Index in the extracted vector.
@@ -387,6 +409,39 @@ def diag_mat_mat(lin_op):
     return [sp.coo_matrix((val_arr, (row_arr, col_arr)),
                           (rows, rows**2)).tocsc()]
 
+def upper_tri_mat(lin_op):
+    """Returns the coefficients matrix for UPPER_TRI linear op.
+
+    Parameters
+    ----------
+    lin_op : LinOp
+        The upper tri linear op.
+
+    Returns
+    -------
+    SciPy CSC matrix
+        The matrix to vectorize the upper triangle.
+    """
+    rows, cols = lin_op.args[0].size
+
+    val_arr = []
+    row_arr = []
+    col_arr = []
+    count = 0
+    for i in range(rows):
+        for j in range(cols):
+            if j > i:
+                # Index in the original matrix.
+                col_arr.append(j*rows + i)
+                # Index in the extracted vector.
+                row_arr.append(count)
+                val_arr.append(1.0)
+                count += 1
+
+    entries, _ = lin_op.size
+    return [sp.coo_matrix((val_arr, (row_arr, col_arr)),
+                          (entries, rows*cols)).tocsc()]
+
 def conv_mat(lin_op):
     """Returns the coefficient matrix for CONV linear op.
 
@@ -449,8 +504,8 @@ def stack_mats(lin_op, vertical):
             col_offset = arg.size[0]
             offset_incr = arg.size[0]*arg.size[1]
 
-        for i in xrange(arg.size[0]):
-            for j in xrange(arg.size[1]):
+        for i in range(arg.size[0]):
+            for j in range(arg.size[1]):
                 row_arr.append(i + j*col_offset + offset)
                 col_arr.append(i + j*arg.size[0])
                 val_arr.append(1)
@@ -470,6 +525,7 @@ TYPE_TO_FUNC = {
     lo.PROMOTE: promote_mat,
     lo.NEG: neg_mat,
     lo.MUL: mul_mat,
+    lo.RMUL: rmul_mat,
     lo.MUL_ELEM: mul_elemwise_mat,
     lo.DIV: div_mat,
     lo.SUM_ENTRIES: sum_entries_mat,
@@ -480,6 +536,7 @@ TYPE_TO_FUNC = {
     lo.SUM: lambda lin_op: [1]*len(lin_op.args),
     lo.DIAG_VEC: diag_vec_mat,
     lo.DIAG_MAT: diag_mat_mat,
+    lo.UPPER_TRI: upper_tri_mat,
     lo.CONV: conv_mat,
     lo.HSTACK: lambda lin_op: stack_mats(lin_op, False),
     lo.VSTACK: lambda lin_op: stack_mats(lin_op, True),
