@@ -48,45 +48,16 @@ SOLUTION_PRESENT = [OPTIMAL, OPTIMAL_INACCURATE]
 INF_OR_UNB = [INFEASIBLE, INFEASIBLE_INACCURATE,
               UNBOUNDED, UNBOUNDED_INACCURATE]
 
-# Map of solver status to cvxpy status.
+# Solver names.
 CVXOPT = "CVXOPT"
-CVXOPT_STATUS = {'optimal': OPTIMAL,
-                 'primal infeasible': INFEASIBLE,
-                 'dual infeasible': UNBOUNDED,
-                 'unknown': SOLVER_ERROR}
+GLPK = "GLPK"
+GLPK_MI = "GLPK_MI"
 ECOS = "ECOS"
-ECOS_STATUS = {0: OPTIMAL,
-               1: INFEASIBLE,
-               2: UNBOUNDED,
-               10: OPTIMAL_INACCURATE,
-               11: INFEASIBLE_INACCURATE,
-               12: UNBOUNDED_INACCURATE,
-               -1: SOLVER_ERROR,
-               -2: SOLVER_ERROR,
-               -3: SOLVER_ERROR,
-               -7: SOLVER_ERROR}
 ECOS_BB = "ECOS_BB"
 SCS = "SCS"
-SCS_STATUS = {"Solved": OPTIMAL,
-              "Solved/Inaccurate": OPTIMAL_INACCURATE,
-              "Unbounded": UNBOUNDED,
-              "Unbounded/Inaccurate": UNBOUNDED_INACCURATE,
-              "Infeasible": INFEASIBLE,
-              "Infeasible/Inaccurate": INFEASIBLE_INACCURATE,
-              "Failure": SOLVER_ERROR,
-              "Indeterminate": SOLVER_ERROR}
-
-SOLVER_STATUS = {CVXOPT: CVXOPT_STATUS,
-                 ECOS: ECOS_STATUS,
-                 ECOS_BB: ECOS_STATUS,
-                 SCS: SCS_STATUS}
-
-# Solver capabilities.
-SOLVERS = [ECOS, ECOS_BB, CVXOPT, SCS]
-SDP_CAPABLE = [CVXOPT, SCS]
-EXP_CAPABLE = [CVXOPT, SCS]
-SOCP_CAPABLE = [ECOS, ECOS_BB, CVXOPT, SCS]
-MIP_CAPABLE = [ECOS_BB]
+GUROBI_LIN = "GUROBI_LIN"
+SOLVERS = [ECOS, ECOS_BB, CVXOPT, GLPK,
+           GLPK_MI, SCS, GUROBI_LIN]
 
 # Map of constraint types.
 EQ, LEQ, SOC, SOC_EW, SDP, EXP, BOOL, INT = range(8)
@@ -110,3 +81,15 @@ OBJ_OFFSET = "obj_offset"
 PRIMAL = "primal"
 EQ_DUAL = "eq_dual"
 INEQ_DUAL = "ineq_dual"
+
+# Keys for problem data dict.
+C = "c"
+OFFSET = "offset"
+A = "A"
+B = "b"
+G = "G"
+H = "h"
+F = "F"
+DIMS = "dims"
+BOOL_IDX = "bool_vars_idx"
+INT_IDX = "int_vars_idx"
