@@ -17,6 +17,7 @@ You should have received a copy of the GNU General Public License
 along with CVXPY.  If not, see <http://www.gnu.org/licenses/>.
 """
 
+from __future__ import print_function
 from cvxpy import *
 import cvxpy.interface as intf
 import numpy as np
@@ -272,6 +273,54 @@ class TestExamples(BaseTest):
         print(a.value)
         print(b.value)
 
+    def test_advanded(self):
+        """Code from the advanced tutorial.
+        """
+        # Solving a problem with different solvers.
+        x = Variable(2)
+        obj = Minimize(x[0] + norm(x, 1))
+        constraints = [x >= 2]
+        prob = Problem(obj, constraints)
+
+        # Solve with ECOS.
+        prob.solve(solver=ECOS)
+        print("optimal value with ECOS:", prob.value)
+        self.assertAlmostEqual(prob.value, 6)
+
+        # Solve with ECOS_BB.
+        prob.solve(solver=ECOS_BB)
+        print("optimal value with ECOS_BB:", prob.value)
+        self.assertAlmostEqual(prob.value, 6)
+
+        # Solve with CVXOPT.
+        prob.solve(solver=CVXOPT)
+        print("optimal value with CVXOPT:", prob.value)
+        self.assertAlmostEqual(prob.value, 6)
+
+        # Solve with SCS.
+        prob.solve(solver=SCS)
+        print("optimal value with SCS:", prob.value)
+        self.assertAlmostEqual(prob.value, 6, places=3)
+
+        if GLPK in installed_solvers():
+            # Solve with GLPK.
+            prob.solve(solver=GLPK)
+            print("optimal value with GLPK:", prob.value)
+            self.assertAlmostEqual(prob.value, 6)
+
+            # Solve with GLPK_MI.
+            prob.solve(solver=GLPK_MI)
+            print("optimal value with GLPK_MI:", prob.value)
+            self.assertAlmostEqual(prob.value, 6)
+
+        if GUROBI_LIN in installed_solvers():
+            # Solve with Gurobi.
+            prob.solve(solver=GUROBI_LIN)
+            print("optimal value with GUROBI_LIN:", prob.value)
+            self.assertAlmostEqual(prob.value, 6)
+
+        print(installed_solvers())
+
     def test_log_det(self):
         # Generate data
         x = np.matrix("0.55  0.0;"
@@ -565,19 +614,23 @@ class TestExamples(BaseTest):
         x = Variable()
         prob = Problem(Minimize(square(x)), [x == 2])
         # Get ECOS arguments.
-        c, G, h, dims, A, b = prob.get_problem_data(ECOS)
+        data = prob.get_problem_data(ECOS)
+
+        # Get ECOS_BB arguments.
+        data = prob.get_problem_data(ECOS_BB)
 
         # Get CVXOPT arguments.
-        c, G, h, dims, A, b = prob.get_problem_data(CVXOPT)
+        data = prob.get_problem_data(CVXOPT)
 
         # Get SCS arguments.
-        data, dims = prob.get_problem_data(SCS)
+        data = prob.get_problem_data(SCS)
 
         import ecos
         # Get ECOS arguments.
-        c, G, h, dims, A, b = prob.get_problem_data(ECOS)
+        data = prob.get_problem_data(ECOS)
         # Call ECOS solver.
-        solver_output = ecos.solve(c, G, h, dims, A, b)
+        solver_output = ecos.solve(data["c"], data["G"], data["h"],
+                                   data["dims"], data["A"], data["b"])
         # Unpack raw solver output.
         prob.unpack_results(ECOS, solver_output)
 
