@@ -347,10 +347,13 @@ class TestExpressions(BaseTest):
         exp = [[1], [2]] + c*self.C
         self.assertEqual(exp.sign, u.Sign.UNKNOWN_KEY)
 
-        # Scalar constants on the right should be moved left
-        # instead of taking the transpose.
+        # Scalar constants on the right should be moved left.
         expr = self.C*2
-        self.assertEqual(expr.args[1].value, 2)
+        self.assertEqual(expr.args[0].value, 2)
+
+        # Scalar variables on the left should be moved right.
+        expr = self.a*[2,1]
+        self.assertItemsAlmostEqual(expr.args[0].value, [2,1])
 
     # Test the DivExpresion class.
     def test_div_expression(self):
@@ -555,7 +558,10 @@ class TestExpressions(BaseTest):
         x = Variable(4)
         Problem(Minimize(0), [x[::-1] == c]).solve()
         self.assertItemsAlmostEqual(x.value, [4, 3, 2, 1])
-        self.assertEquals(x.size, (4, 1))
+        self.assertEquals(x[::-1].size, (4, 1))
+
+        x = Variable(2)
+        self.assertEquals(x[::-1].size, (2, 1))
 
     def test_logical_indices(self):
         """Test indexing with logical arrays.
