@@ -23,7 +23,7 @@ from cvxpy.expressions.constants import Constant, Parameter
 from cvxpy.expressions.variables import Variable, Semidef, Bool
 from cvxpy.problems.objective import *
 from cvxpy.problems.problem import Problem
-from cvxpy.problems.solvers.utilities import SOLVERS
+from cvxpy.problems.solvers.utilities import SOLVERS, installed_solvers
 from cvxpy.problems.problem_data.sym_data import SymData
 import cvxpy.interface as intf
 import cvxpy.lin_ops.lin_utils as lu
@@ -106,25 +106,25 @@ class TestProblem(BaseTest):
             Problem(Maximize(exp(self.a))).get_problem_data(s.ECOS)
         self.assertEqual(str(cm.exception), "The solver ECOS cannot solve the problem.")
 
-        args = Problem(Maximize(exp(self.a) + 2)).get_problem_data(s.SCS)
-        data, dims = args
+        data = Problem(Maximize(exp(self.a) + 2)).get_problem_data(s.SCS)
+        dims = data["dims"]
         self.assertEqual(dims['ep'], 1)
         self.assertEqual(data["c"].shape, (2,))
         self.assertEqual(data["A"].shape, (3, 2))
 
-        args = Problem(Minimize(norm(self.x) + 3)).get_problem_data(s.ECOS)
-        c, G, h, dims, A, b = args
+        data = Problem(Minimize(norm(self.x) + 3)).get_problem_data(s.ECOS)
+        dims = data["dims"]
         self.assertEqual(dims["q"], [3])
-        self.assertEqual(c.shape, (3,))
-        self.assertEqual(A.shape, (0, 3))
-        self.assertEqual(G.shape, (3, 3))
+        self.assertEqual(data["c"].shape, (3,))
+        self.assertEqual(data["A"].shape, (0, 3))
+        self.assertEqual(data["G"].shape, (3, 3))
 
-        args = Problem(Minimize(norm(self.x) + 3)).get_problem_data(s.CVXOPT)
-        c, G, h, dims, A, b = args
+        data = Problem(Minimize(norm(self.x) + 3)).get_problem_data(s.CVXOPT)
+        dims = data["dims"]
         self.assertEqual(dims["q"], [3])
-        self.assertEqual(c.size, (3, 1))
-        self.assertEqual(A.size, (0, 3))
-        self.assertEqual(G.size, (3, 3))
+        self.assertEqual(data["c"].size, (3, 1))
+        self.assertEqual(data["A"].size, (0, 3))
+        self.assertEqual(data["G"].size, (3, 3))
 
     def test_unpack_results(self):
         """Test unpack results method.
@@ -135,7 +135,8 @@ class TestProblem(BaseTest):
 
         prob = Problem(Minimize(exp(self.a)), [self.a == 0])
         args = prob.get_problem_data(s.SCS)
-        results_dict = scs.solve(*args)
+        data = {"c": args["c"], "A": args["A"], "b": args["b"]}
+        results_dict = scs.solve(data, args["dims"])
         prob = Problem(Minimize(exp(self.a)), [self.a == 0])
         prob.unpack_results(s.SCS, results_dict)
         self.assertAlmostEqual(self.a.value, 0, places=4)
@@ -144,7 +145,8 @@ class TestProblem(BaseTest):
 
         prob = Problem(Minimize(norm(self.x)), [self.x == 0])
         args = prob.get_problem_data(s.ECOS)
-        results_dict = ecos.solve(*args)
+        results_dict = ecos.solve(args["c"], args["G"], args["h"],
+                                  args["dims"], args["A"], args["b"])
         prob = Problem(Minimize(norm(self.x)), [self.x == 0])
         prob.unpack_results(s.ECOS, results_dict)
         self.assertItemsAlmostEqual(self.x.value, [0,0])
@@ -153,7 +155,8 @@ class TestProblem(BaseTest):
 
         prob = Problem(Minimize(norm(self.x)), [self.x == 0])
         args = prob.get_problem_data(s.CVXOPT)
-        results_dict = cvxopt.solvers.conelp(*args)
+        results_dict = cvxopt.solvers.conelp(args["c"], args["G"], args["h"],
+                                             args["dims"], args["A"], args["b"])
         prob = Problem(Minimize(norm(self.x)), [self.x == 0])
         prob.unpack_results(s.CVXOPT, results_dict)
         self.assertItemsAlmostEqual(self.x.value, [0,0])
@@ -162,33 +165,40 @@ class TestProblem(BaseTest):
 
     # Test silencing and enabling solver messages.
     def test_verbose(self):
+        import sys
         # From http://stackoverflow.com/questions/5136611/capture-stdout-from-a-script-in-python
         # setup the environment
         outputs = {True: [], False: []}
         backup = sys.stdout
-
         # ####
         for verbose in [True, False]:
-            for solver in s.SOLVERS:
+            for solver in installed_solvers():
+                # Don't test GLPK because there's a race
+                # condition in setting CVXOPT solver options.
+                if solver in ["GLPK", "GLPK_MI"]:
+                    continue
                 sys.stdout = StringIO() # capture output
-                p = Problem(Minimize(self.a + self.x[0]), [self.a >= 2, self.x >= 2])
-                if solver in s.MIP_CAPABLE:
+
+                p = Problem(Minimize(self.a + self.x[0]),
+                                     [self.a >= 2, self.x >= 2])
+                if SOLVERS[solver].MIP_CAPABLE:
                     p.constraints.append(Bool() == 0)
                 p.solve(verbose=verbose, solver=solver)
-                if solver in s.EXP_CAPABLE:
+                if SOLVERS[solver].EXP_CAPABLE:
                     p = Problem(Minimize(self.a), [log(self.a) >= 2])
                     p.solve(verbose=verbose, solver=solver)
-                out = sys.stdout.getvalue() # release output
-                outputs[verbose].append(out.upper())
-        # ####
 
+                out = sys.stdout.getvalue() # release output
+
+                outputs[verbose].append((out, solver))
+        # ####
         sys.stdout.close()  # close the stream
         sys.stdout = backup # restore original stdout
-
-        for output in outputs[True]:
+        for output, solver in outputs[True]:
+            print(solver)
             assert len(output) > 0
-        for output in outputs[False]:
-            print(output)
+        for output, solver in outputs[False]:
+            print(solver)
             assert len(output) == 0
 
     # Test registering other solve methods.
@@ -1086,7 +1096,9 @@ class TestProblem(BaseTest):
         x = Variable()
         obj = Maximize(sqrt(x))
         prob = Problem(obj)
-        c, G, h, dims, A, b = prob.get_problem_data(s.ECOS)
+        data = prob.get_problem_data(s.ECOS)
+        A = data["A"]
+        G = data["G"]
         for row in range(A.shape[0]):
             assert A[row, :].nnz > 0
         for row in range(G.shape[0]):
