@@ -205,6 +205,17 @@ class TestSCS(BaseTest):
         assert problem.status == cvxpy.OPTIMAL_INACCURATE, problem.status
         return [eta1.value, eta2.value, eta3.value]
 
+    def test_warm_start(self):
+        """Test warm starting.
+        """
+        x = Variable(10)
+        obj = Minimize(sum_entries(exp(x)))
+        prob = Problem(obj, [sum_entries(x) == 1])
+        result = prob.solve(solver=SCS)
+        assert prob.solve(solver=SCS, verbose=True) == result
+        # TODO Probably a bad check. Ought to be the same.
+        assert prob.solve(solver=SCS, warm_start=True, verbose=True) != result
+
     # def test_kl_div(self):
     #     """Test the kl_div atom.
     #     """
